@@ -2,7 +2,9 @@
 from .statistics_functions import *
 
 __all__ = [
+    'cmf',
     'odds2prob',
+    'pmf',
     'prob2odds',
     'prob2score',
     'score2prob'
